//--------------------------------------------------------------
// File     : stm32_ub_touch_480x272.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_TOUCH_480x272_H
#define __STM32F4_UB_TOUCH_480x272_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_adc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"



//----------------------------------------------------------------------
// mess intervall fr Touch
// (nicht kleiner als 10ms einstellen)
//----------------------------------------------------------------------
#define   TOUCH_INTERVALL_MS      50   // 50ms



//----------------------------------------------------------------------
// adc defines (grenzwerte)
//----------------------------------------------------------------------
#define   TOUCH_ADC_MAXWERT     1023 // 10bit
#define   TOUCH_ADC_MESSUNGEN    32  // anzahl der messungen (>=16)
#define   TOUCH_ADC_MINXWERT     60  // x-achse (minimum)
#define   TOUCH_ADC_MAXXWERT    945  // x-achse (maximum)
#define   TOUCH_ADC_MINYWERT     90  // y-achse (minimum)
#define   TOUCH_ADC_MAXYWERT    935  // y-achse (maximum)
#define   TOUCH_ADC_MAXDELTA     20  // delta   (maximum)



//----------------------------------------------------------------------
// adc defines (abgleichwerte)
//----------------------------------------------------------------------
#define   TOUCH_SIZE_X          480  // x-achse in pixel
#define   TOUCH_SIZE_Y          272  // y-achse in pixel
#define   TOUCH_ADC_X0          930  // adc-wert bei xpos=0
#define   TOUCH_ADC_X480        75   // adc-wert bei xpos=480
#define   TOUCH_ADC_Y0          920  // adc-wert bei ypos=0
#define   TOUCH_ADC_Y272        105  // adc-wert bei ypos=272





//----------------------------------------------------------------------
// defines der Touch-Pins
//----------------------------------------------------------------------
#define   TOUCH_GPIO_CLOCK       RCC_AHB1Periph_GPIOA
#define   TOUCH_GPIO_PORT_XR     GPIOA
#define   TOUCH_GPIO_PIN_XR      GPIO_Pin_0
#define   TOUCH_GPIO_PORT_YD     GPIOA
#define   TOUCH_GPIO_PIN_YD      GPIO_Pin_1
#define   TOUCH_GPIO_PORT_XL     GPIOA
#define   TOUCH_GPIO_PIN_XL      GPIO_Pin_2
#define   TOUCH_GPIO_PORT_YU     GPIOA
#define   TOUCH_GPIO_PIN_YU      GPIO_Pin_3
//----------------------------------------------------------------------
#define   TOUCH_ADC_CLOCK        RCC_APB2Periph_ADC3
#define   TOUCH_ADC_NAME         ADC3
#define   TOUCH_ADC_CH_X         ADC_Channel_3 // YU=PA3
#define   TOUCH_ADC_CH_Y         ADC_Channel_2 // XL=PA2


//----------------------------------------------------------------------
// timer defines
// (Timer-ISR muss auf 1ms eingestellt werden)
//----------------------------------------------------------------------
#define   TOUCH_TIMER_CLOCK        RCC_APB1Periph_TIM7
#define   TOUCH_TIMER_NAME         TIM7    // TIM7 = 84MHz
#define   TOUCH_TIMER_PRESCALE     84-1    // 84MHz/84 = 1MHz
#define   TOUCH_TIMER_PERIOD       1000-1  // 1MHz/1000 = 1kHz = 1ms
#define   TOUCH_TIMER_IRQ          TIM7_IRQn
#define   TOUCH_TIMER_ISR          TIM7_IRQHandler


//----------------------------------------------------------------------
#define   TOUCH_MODE_X   0  // x
#define   TOUCH_MODE_Y   1  // y
#define   TOUCH_MODE_S   2  // sleep
#define   TOUCH_MODE_I   3  // init



//-----------------------------------------
// Touch-Status
//-----------------------------------------
typedef enum {
  TOUCH_PRESSED  = 0,   // Touch ist betaetigt
  TOUCH_RELEASED = 1	// Touch ist nicht betaetigt
}Touch_Status_t;



//-----------------------------------------
// Globale Struktur der Touch-Daten
//-----------------------------------------
typedef struct {
  Touch_Status_t status;
  uint16_t xp;
  uint16_t yp;
}Touch_Data_t;
Touch_Data_t Touch_Data;




//----------------------------------------------------------------------
// roh daten vom Touch
//----------------------------------------------------------------------
typedef struct {
  uint16_t x_adcwert;  // xpos als adc-wert
  uint16_t y_adcwert;  // ypos als adc-wert  
  uint16_t timer_ms;   // fuer Timer
  uint16_t adc[TOUCH_ADC_MESSUNGEN];
}TOUCH_RAW_t;
TOUCH_RAW_t TOUCH_RAW;



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_Touch_Init(void);





//--------------------------------------------------------------
#endif // __STM32F4_UB_TOUCH_480x272_H
